@@ -6,5 +6,5 @@ from xlsx_lib.domain.electronic.element_component import ElementComponent
 
 
 class ElectronicElement(CamelModel):
-    name: str
+    name: Optional[str]
     components: Optional[List[ElementComponent]]
