@@ -6,5 +6,5 @@ from xlsx_lib.domain.engine.section_element import SectionElement
 
 
 class EngineSection(CamelModel):
-    name: str
+    name: Optional[str]
     section_elements: Optional[List[SectionElement]]
