@@ -35,14 +35,6 @@ class FrameSheet(Sheet):
 
         self.process_frame_elements()
 
-        new_frame_elements: List[FrameElement] = []
-
-        for element in self.frame_elements:
-            if element.name not in [x.name for x in new_frame_elements]:
-                new_frame_elements.append(element)
-
-        self.frame_elements = new_frame_elements
-
     def process_frame_elements(self) -> None:
         col_index: int = self.start_col
         row_index: int = self.start_row
