@@ -2,7 +2,7 @@ from typing import List
 
 from camel_model.camel_model import CamelModel
 
-from domain.shared.TextLine import TextLine
+from xlsx_lib.domain.shared.TextLine import TextLine
 from xlsx_lib.domain.hiss_immobilizer.Problem import Problem
 
 
