@@ -2,7 +2,7 @@ from typing import List, Optional
 
 from camel_model.camel_model import CamelModel
 
-from domain.power_supply.component_attribute import ComponentAttribute
+from xlsx_lib.domain.power_supply.component_attribute import ComponentAttribute
 
 
 class PowerSupplyComponent(CamelModel):
