@@ -19,12 +19,12 @@ def get_power_supply_cell_value_type(cell: Cell) -> PowerSupplyCellValueType:
 
 
 class PowerSupplySheet(Sheet):
-    components: List[PowerSupplyComponent] = []
-
     def __init__(
             self,
             worksheet: Worksheet,
     ):
+        self.components: List[PowerSupplyComponent] = []
+
         super().__init__(
             worksheet=worksheet,
             end_of_sheet_rows_limit=20,
