@@ -5,8 +5,9 @@ from openpyxl.cell import Cell
 from openpyxl.worksheet.worksheet import Worksheet
 from openpyxl_image_loader import SheetImageLoader
 
-from xlsx_lib.domain.shared.text_line import TextLine
-from xlsx_lib.domain.distribution.new_distribution_image import NewImage
+from xlsx_lib.domain.shared.NewImageData import NewImageData
+from xlsx_lib.domain.shared.NewImageFile import NewImageFile
+from xlsx_lib.domain.shared.TextLine import TextLine
 from xlsx_lib.domain.smart_key.Fault import Fault
 from xlsx_lib.domain.smart_key.SmartKeyCellValueKind import SmartKeyCellValueKind
 from xlsx_lib.domain.smart_key.SmartKeyData import SmartKeyData
@@ -28,11 +29,13 @@ class SmartKeySheet(Sheet):
             worksheet: Worksheet,
     ):
         self.smart_key_data: SmartKeyData = SmartKeyData()
+
+        self.smart_key_images: List[NewImageFile] = []
+
+        self.stored_flash_pattern_images_data: List[NewImageData] = []
         self.stored_flashs_number_by_time: List[str] = []
         self.stored_parts_to_review: List[str] = []
 
-        self.smart_key_images: List[NewImage] = []
-
         super().__init__(
             worksheet=worksheet,
             end_of_sheet_rows_limit=20,
@@ -43,19 +46,27 @@ class SmartKeySheet(Sheet):
         image_loader = SheetImageLoader(worksheet)
 
         for image in worksheet._images:
-            file_name: str = f"{uuid.uuid4()}.{image.format}"
+            filename: str = f"{uuid.uuid4()}.{image.format}"
 
             self.smart_key_images.append(
-                NewImage(
-                    file_name=file_name,
+                NewImageFile(
+                    filename=filename,
                     file=image.ref,
                 )
             )
 
+            self.stored_flash_pattern_images_data.append(
+                NewImageData(
+                    filename=filename,
+                    width=image.width,
+                    height=image.height
+                )
+            )
+
         self.process_data()
 
         for i in range(len(self.smart_key_data.faults_list)):
-            self.smart_key_data.faults_list[i].flash_pattern_image = self.smart_key_images[i].file_name
+            self.smart_key_data.faults_list[i].flash_pattern_image = self.stored_flash_pattern_images_data[i]
 
     def process_data(self) -> None:
         col_index: int = self.start_col
@@ -111,7 +122,7 @@ class SmartKeySheet(Sheet):
                     Fault(
                         fault_kind=[TextLine(text=values[0])],
                         flashs_number_by_time=self.stored_flashs_number_by_time.pop() if len(self.stored_flashs_number_by_time) != 0 else None,
-                        parts_to_review=[TextLine(text=self.stored_parts_to_review.pop())] if len(self.stored_parts_to_review) != 0 else None
+                        parts_to_review=[TextLine(text=self.stored_parts_to_review.pop())] if len(self.stored_parts_to_review) != 0 else None,
                     )
                 )
 
